---
name: Feature request
about: Suggest an idea
title: ''
labels: 'feature'
assignees: ''

---

## Problem

**Is your feature request related to a problem? Please describe.**
A clear and concise description of what the problem is. Ex. I'm always frustrated when [...]

## Solution

**Describe the solution you'd like**
A clear and concise description of what you want to happen.

## Alternative Solution

**Describe alternatives you've considered**
A clear and concise description of any alternative solutions or features you've considered.
It's *optional*.

## Additional Context

Add any other context or screenshots about the feature request here.
